@@ -21,18 +21,18 @@ def _check_adp_token(value) -> None:
     if not isinstance(value, str):
         raise TypeError("type of adp_token is not str")
 
-    parts = re.findall(r"\{.*?\}", value)
+    parts = re.findall(r"{.*?}", value)
     if len(parts) != 5:
         raise ValueError("adp_token have wrong format")
 
     adp_token_as_dict = dict()
     for part in parts:
-        search_pieces = re.search('\{(.*?)\:(.*?)\}', part)
+        search_pieces = re.search('{(.*?):(.*?)}', part)
         key = search_pieces.group(1)
         value = search_pieces.group(2)
         adp_token_as_dict[key] = value
 
-        allowed_keys = {"enc", "key", "iv", "name", "serial"}
+    allowed_keys = {"enc", "key", "iv", "name", "serial"}
     if not adp_token_as_dict.keys() == allowed_keys:
         raise ValueError("adp_token have wrong format")
 
@@ -76,11 +76,10 @@ def _check_expires(value) -> Optional[float]:
 
 
 def _check_locales(value) -> Optional[Locale]:
-    if isinstance(value, Locale):
-        pass
-    elif isinstance(value, str):
+    if isinstance(value, str):
         return Locale(value.lower())
-    else:
+
+    if not isinstance(value, Locale):
         raise TypeError("Locale error")
 
 
@@ -94,9 +93,9 @@ def _check_filename(value) -> Union[pathlib.Path, pathlib.WindowsPath]:
             raise Exception("File error")
 
 
-def _check_crypter(value) -> None:
+def _check_crypter(value) -> Any:
     # TODO: write checks
-    pass
+    return value
 
 
 def _check_encryption(value) -> None:
@@ -123,7 +122,7 @@ string_function_map = {
 
 
 def test_convert(key: str, value: Any) -> Any:
-    if key in string_function_map:
+    if key in string_function_map and value is not None:
         return string_function_map[key](value) or value
 
     return value
